@@ -1,6 +1,6 @@
+( cd usr/doc/gettext-0.17 ; rm -rf ABOUT-NLS )
+( cd usr/doc/gettext-0.17 ; ln -sf ../../share/gettext/ABOUT-NLS ABOUT-NLS )
 ( cd usr/lib ; rm -rf libasprintf.so.0 )
 ( cd usr/lib ; ln -sf libasprintf.so.0.0.0 libasprintf.so.0 )
 ( cd usr/lib ; rm -rf libasprintf.so )
 ( cd usr/lib ; ln -sf libasprintf.so.0.0.0 libasprintf.so )
-( cd usr/doc/gettext-0.15 ; rm -rf ABOUT-NLS )
-( cd usr/doc/gettext-0.15 ; ln -sf /usr/share/gettext/ABOUT-NLS ABOUT-NLS )
